import pandas as pd

# https://public.opendatasoft.com/explore/dataset/geonames-all-cities-with-a-population-1000/
# https://download.geonames.org/export/dump/cities1000.zip
# https://download.geonames.org/export/dump/admin1CodesASCII.txt
# https://download.geonames.org/export/dump/admin2Codes.txt


cities = pd.read_csv("geonames-all-cities-with-a-population-1000.csv",
                     sep=";")

print(cities)
print(cities[["Name", "Population", "Coordinates"]])

largest = cities.sort_values("Population", ascending=False)
print(largest[["Name", "Population"]].iloc[:10])

cities = cities[cities["Population"] >= 1000]

import matplotlib.pyplot as plt
fig, ax = plt.subplots(figsize=(6, 4))
ax.scatter(cities['Elevation'], cities['Population'], alpha=0.2)
ax.set_xlabel('Elevation')
ax.set_ylabel('Population')
ax.set_yscale('log')
fig.savefig("ele-pop.png")

na_cities = cities[
    cities["Country Code"].isin(["CA", "US", "MX"]) ]
avg_pop = na_cities.groupby("Country Code") \
        .agg({"Population": "mean"})
print(avg_pop)

from scipy.stats import mannwhitneyu
canada = cities[cities["Country Code"] == "CA"]
usa = cities[cities["Country Code"] == "US"]
u = mannwhitneyu(canada["Population"], usa["Population"])
print(u.pvalue)


ac_names = ["code", "Admin Name", "Admin Name ascii",
            "Admin geonameid"]
admin_codes = pd.read_csv("admin1CodesASCII.txt", sep="\t",
                          names=ac_names)
admin_codes = admin_codes[["code", "Admin Name"]]
print(admin_codes[admin_codes["code"].str.startswith("CA")])

cities["code"] = cities["Country Code"] + "." \
                 + cities["Admin1 Code"]
merged = pd.merge(cities, admin_codes, on="code")
canada = merged[merged["Country Code"] == "CA"]
print(canada[["Name", "code", "Admin Name"]])

ns = canada[canada["Admin Name"] == "Nova Scotia"]
qc = canada[canada["Admin Name"] == "Quebec"]
u = mannwhitneyu(ns['Population'], qc['Population'])
print(u.pvalue)

na_cities["is_big"] = na_cities["Population"] > 20000
counts = pd.crosstab(na_cities["Country Code"],
                     na_cities["is_big"])
print(counts)
from scipy.stats import chi2_contingency
print(chi2_contingency(counts).pvalue)